@@ -230,6 +230,12 @@ impl App<'_> {
                 AppEvent::ClearHelp => {
                     self.clear_help();
                 }
+                AppEvent::SelectOlderCommit => {
+                    self.select_older_commit();
+                }
+                AppEvent::SelectNewerCommit => {
+                    self.select_newer_commit();
+                }
                 AppEvent::CopyToClipboard { name, value } => {
                     self.copy_to_clipboard(name, value);
                 }
@@ -531,6 +537,22 @@ impl App<'_> {
         }
     }
 
+    fn select_older_commit(&mut self) {
+        if let View::Detail(ref mut view) = self.view {
+            view.select_older_commit(self.repository);
+        } else if let View::UserCommand(ref mut view) = self.view {
+            view.select_older_commit(self.repository, self.view_area);
+        }
+    }
+
+    fn select_newer_commit(&mut self) {
+        if let View::Detail(ref mut view) = self.view {
+            view.select_newer_commit(self.repository);
+        } else if let View::UserCommand(ref mut view) = self.view {
+            view.select_newer_commit(self.repository, self.view_area);
+        }
+    }
+
     fn clear_status_line(&mut self) {
         self.status_line = StatusLine::None;
     }
